@@ -54,14 +54,31 @@ class Security(Base):
 
 
 def get_default_session():
-    """ Return the default session. The path is read from the default config. """
-    from .config import Config, ConfigKeys
+    '''
+    Return the default database session. The db file path is read from the config.
+    Implementation using the Yaml config.
+    '''
+    from pricedb.config import package_name
+    from usersconfig.configuration import Configuration
+    from .config import ConfigKeys
 
-    db_path = Config().get(ConfigKeys.price_database)
+    cfg = Configuration(package_name).load()
+    # print(cfg)
+    
+    db_path = cfg[ConfigKeys.price_database_path.name]
     if not db_path:
         raise ValueError("Price database not set in the configuration file!")
     return get_session(db_path)
 
+# def get_default_session():
+#     """ Return the default session. The path is read from the default config. """
+#     from .config import Config, ConfigKeys
+
+#     db_path = Config().get(ConfigKeys.price_database_path)
+#     if not db_path:
+#         raise ValueError("Price database not set in the configuration file!")
+#     return get_session(db_path)
+
 def get_session(db_path: str):
     """ Creates and opens a database session """
     # connection
